paidiverpy.utils.docker
=======================

.. py:module:: paidiverpy.utils.docker

.. autoapi-nested-parse::

   This module contains utility functions for Docker.

   ..
       !! processed by numpydoc !!


Functions
---------

.. autoapisummary::

   paidiverpy.utils.docker.is_running_in_docker


Module Contents
---------------

.. py:function:: is_running_in_docker() -> bool

   
   Check if the code is running in a Docker container.

   :returns: Whether the code is running in a Docker container.
   :rtype: bool















   ..
       !! processed by numpydoc !!

